==> pandoc-3.7.0.2.tar.gz: pandoc-3.7.0.2/test/command/7512.md <==
```
% pandoc -t native -f latex
\begin{equation*}
[d,\delta]=0.
\end{equation*}
^D
[ Para [ Math DisplayMath "[d,\\delta]=0." ] ]
```

```
% pandoc -t native -f latex
\begin{table}[htb]
  \begin{tabular}{|c|c|}
       $W$      & rel. err. \\[0mm]
       [$\mu$m] & [\%]\\
  \end{tabular}
\end{table}
^D
[ Table
    ( "" , [] , [] )
    (Caption Nothing [])
    [ ( AlignCenter , ColWidthDefault )
    , ( AlignCenter , ColWidthDefault )
    ]
    (TableHead ( "" , [] , [] ) [])
    [ TableBody
        ( "" , [] , [] )
        (RowHeadColumns 0)
        []
        [ Row
            ( "" , [] , [] )
            [ Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Math InlineMath "W" ] ]
            , Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Str "rel." , Space , Str "err." ] ]
            ]
        , Row
            ( "" , [] , [] )
            [ Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Str "[" , Math InlineMath "\\mu" , Str "m]" ]
                ]
            , Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Str "[%]" ] ]
            ]
        ]
    ]
    (TableFoot ( "" , [] , [] ) [])
]
```

==> pandoc-3.8.tar.gz: pandoc-3.8/test/command/7512.md <==
```
% pandoc -t native -f latex
\begin{equation*}
[d,\delta]=0.
\end{equation*}
^D
[ Para
    [ Math
        DisplayMath
        "\\begin{equation*}\n[d,\\delta]=0.\n\\end{equation*}"
    ]
]
```

```
% pandoc -t native -f latex
\begin{table}[htb]
  \begin{tabular}{|c|c|}
       $W$      & rel. err. \\[0mm]
       [$\mu$m] & [\%]\\
  \end{tabular}
\end{table}
^D
[ Table
    ( "" , [] , [] )
    (Caption Nothing [])
    [ ( AlignCenter , ColWidthDefault )
    , ( AlignCenter , ColWidthDefault )
    ]
    (TableHead ( "" , [] , [] ) [])
    [ TableBody
        ( "" , [] , [] )
        (RowHeadColumns 0)
        []
        [ Row
            ( "" , [] , [] )
            [ Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Math InlineMath "W" ] ]
            , Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Str "rel." , Space , Str "err." ] ]
            ]
        , Row
            ( "" , [] , [] )
            [ Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Str "[" , Math InlineMath "\\mu" , Str "m]" ]
                ]
            , Cell
                ( "" , [] , [] )
                AlignDefault
                (RowSpan 1)
                (ColSpan 1)
                [ Plain [ Str "[%]" ] ]
            ]
        ]
    ]
    (TableFoot ( "" , [] , [] ) [])
]
```
